@@ -43,8 +43,8 @@
 #include <vector.h>
 #include <lang.h>
 
-#define bc_lex_err(l, e) (bc_vm_error((e), (l)->line))
-#define bc_lex_verr(l, e, ...) (bc_vm_error((e), (l)->line, __VA_ARGS__))
+#define bc_lex_err(l, e) (bc_vm_handleError((e), (l)->line))
+#define bc_lex_verr(l, e, ...) (bc_vm_handleError((e), (l)->line, __VA_ARGS__))
 
 #if BC_ENABLED
 
