@@ -46,6 +46,8 @@
 #define DC_ENABLED (1)
 #endif // DC_ENABLED
 
+#include <bcl.h>
+
 typedef enum BcStatus {
 
 	BC_STATUS_SUCCESS = 0,
@@ -58,75 +60,75 @@ typedef enum BcStatus {
 
 } BcStatus;
 
-typedef enum BcError {
+typedef enum BcErr {
 
-	BC_ERROR_MATH_NEGATIVE,
-	BC_ERROR_MATH_NON_INTEGER,
-	BC_ERROR_MATH_OVERFLOW,
-	BC_ERROR_MATH_DIVIDE_BY_ZERO,
+	BC_ERR_MATH_NEGATIVE,
+	BC_ERR_MATH_NON_INTEGER,
+	BC_ERR_MATH_OVERFLOW,
+	BC_ERR_MATH_DIVIDE_BY_ZERO,
 
-	BC_ERROR_FATAL_ALLOC_ERR,
-	BC_ERROR_FATAL_IO_ERR,
-	BC_ERROR_FATAL_FILE_ERR,
-	BC_ERROR_FATAL_BIN_FILE,
-	BC_ERROR_FATAL_PATH_DIR,
-	BC_ERROR_FATAL_OPTION,
-	BC_ERROR_FATAL_OPTION_NO_ARG,
-	BC_ERROR_FATAL_OPTION_ARG,
+	BC_ERR_FATAL_ALLOC_ERR,
+	BC_ERR_FATAL_IO_ERR,
+	BC_ERR_FATAL_FILE_ERR,
+	BC_ERR_FATAL_BIN_FILE,
+	BC_ERR_FATAL_PATH_DIR,
+	BC_ERR_FATAL_OPTION,
+	BC_ERR_FATAL_OPTION_NO_ARG,
+	BC_ERR_FATAL_OPTION_ARG,
 
-	BC_ERROR_EXEC_IBASE,
-	BC_ERROR_EXEC_OBASE,
-	BC_ERROR_EXEC_SCALE,
-	BC_ERROR_EXEC_READ_EXPR,
-	BC_ERROR_EXEC_REC_READ,
-	BC_ERROR_EXEC_TYPE,
+	BC_ERR_EXEC_IBASE,
+	BC_ERR_EXEC_OBASE,
+	BC_ERR_EXEC_SCALE,
+	BC_ERR_EXEC_READ_EXPR,
+	BC_ERR_EXEC_REC_READ,
+	BC_ERR_EXEC_TYPE,
 
-	BC_ERROR_EXEC_STACK,
+	BC_ERR_EXEC_STACK,
 
-	BC_ERROR_EXEC_PARAMS,
-	BC_ERROR_EXEC_UNDEF_FUNC,
-	BC_ERROR_EXEC_VOID_VAL,
+	BC_ERR_EXEC_PARAMS,
+	BC_ERR_EXEC_UNDEF_FUNC,
+	BC_ERR_EXEC_VOID_VAL,
 
-	BC_ERROR_PARSE_EOF,
-	BC_ERROR_PARSE_CHAR,
-	BC_ERROR_PARSE_STRING,
-	BC_ERROR_PARSE_COMMENT,
-	BC_ERROR_PARSE_TOKEN,
+	BC_ERR_PARSE_EOF,
+	BC_ERR_PARSE_CHAR,
+	BC_ERR_PARSE_STRING,
+	BC_ERR_PARSE_COMMENT,
+	BC_ERR_PARSE_TOKEN,
 #if BC_ENABLED
-	BC_ERROR_PARSE_EXPR,
-	BC_ERROR_PARSE_EMPTY_EXPR,
-	BC_ERROR_PARSE_PRINT,
-	BC_ERROR_PARSE_FUNC,
-	BC_ERROR_PARSE_ASSIGN,
-	BC_ERROR_PARSE_NO_AUTO,
-	BC_ERROR_PARSE_DUP_LOCAL,
-	BC_ERROR_PARSE_BLOCK,
-	BC_ERROR_PARSE_RET_VOID,
-	BC_ERROR_PARSE_REF_VAR,
+	BC_ERR_PARSE_EXPR,
+	BC_ERR_PARSE_EMPTY_EXPR,
+	BC_ERR_PARSE_PRINT,
+	BC_ERR_PARSE_FUNC,
+	BC_ERR_PARSE_ASSIGN,
+	BC_ERR_PARSE_NO_AUTO,
+	BC_ERR_PARSE_DUP_LOCAL,
+	BC_ERR_PARSE_BLOCK,
+	BC_ERR_PARSE_RET_VOID,
+	BC_ERR_PARSE_REF_VAR,
 
-	BC_ERROR_POSIX_NAME_LEN,
-	BC_ERROR_POSIX_COMMENT,
-	BC_ERROR_POSIX_KW,
-	BC_ERROR_POSIX_DOT,
-	BC_ERROR_POSIX_RET,
-	BC_ERROR_POSIX_BOOL,
-	BC_ERROR_POSIX_REL_POS,
-	BC_ERROR_POSIX_MULTIREL,
-	BC_ERROR_POSIX_FOR,
-	BC_ERROR_POSIX_EXP_NUM,
-	BC_ERROR_POSIX_REF,
-	BC_ERROR_POSIX_VOID,
-	BC_ERROR_POSIX_BRACE,
+	BC_ERR_POSIX_NAME_LEN,
+	BC_ERR_POSIX_COMMENT,
+	BC_ERR_POSIX_KW,
+	BC_ERR_POSIX_DOT,
+	BC_ERR_POSIX_RET,
+	BC_ERR_POSIX_BOOL,
+	BC_ERR_POSIX_REL_POS,
+	BC_ERR_POSIX_MULTIREL,
+	BC_ERR_POSIX_FOR,
+	BC_ERR_POSIX_EXP_NUM,
+	BC_ERR_POSIX_REF,
+	BC_ERR_POSIX_VOID,
+	BC_ERR_POSIX_BRACE,
 #endif // BC_ENABLED
 
-	BC_ERROR_NELEMS,
+	BC_ERR_NELEMS,
 
 #if BC_ENABLED
-	BC_ERROR_POSIX_START = BC_ERROR_POSIX_NAME_LEN,
-	BC_ERROR_POSIX_END = BC_ERROR_POSIX_BRACE,
+	BC_ERR_POSIX_START = BC_ERR_POSIX_NAME_LEN,
+	BC_ERR_POSIX_END = BC_ERR_POSIX_BRACE,
 #endif // BC_ENABLED
 
-} BcError;
+} BcErr;
 
 #define BC_ERR_IDX_MATH (0)
 #define BC_ERR_IDX_PARSE (1)
@@ -163,6 +165,16 @@ typedef enum BcError {
 #define BC_MUST_RETURN
 #endif // __STDC_VERSION__
 
+#if defined(__clang__) || defined(__GNUC__)
+#if defined(__has_attribute) && __has_attribute(fallthrough)
+#define BC_FALLTHROUGH __attribute__((fallthrough));
+#else // defined(__has_attribute) && __has_attribute(fallthrough)
+#define BC_FALLTHROUGH
+#endif // defined(__has_attribute) && __has_attribute(fallthrough)
+#else // defined(__clang__) || defined(__GNUC__)
+#define BC_FALLTHROUGH
+#endif //defined(__clang__) || defined(__GNUC__)
+
 // Workarounds for AIX's POSIX incompatibility.
 #ifndef SIZE_MAX
 #define SIZE_MAX __SIZE_MAX__
