@@ -41,10 +41,8 @@
 
 #include <unistd.h>
 
-#include <status.h>
 #include <vector.h>
 #include <read.h>
-#include <vm.h>
 #include <args.h>
 #include <opt.h>
 
@@ -109,7 +107,7 @@ void bc_args(int argc, char *argv[]) {
 			case 'e':
 			{
 				if (vm.no_exit_exprs)
-					bc_vm_verr(BC_ERROR_FATAL_OPTION, "-e (--expression)");
+					bc_vm_verr(BC_ERR_FATAL_OPTION, "-e (--expression)");
 				bc_args_exprs(opts.optarg);
 				break;
 			}
@@ -119,7 +117,7 @@ void bc_args(int argc, char *argv[]) {
 				if (!strcmp(opts.optarg, "-")) vm.no_exit_exprs = true;
 				else {
 					if (vm.no_exit_exprs)
-						bc_vm_verr(BC_ERROR_FATAL_OPTION, "-f (--file)");
+						bc_vm_verr(BC_ERR_FATAL_OPTION, "-f (--file)");
 					bc_args_file(opts.optarg);
 				}
 				break;
