@@ -47,9 +47,6 @@
 #include <bc.h>
 #include <dc.h>
 
-char output_bufs[BC_VM_BUF_SIZE];
-BcVm vm;
-
 int main(int argc, char *argv[]) {
 
 	int s;
