@@ -37,12 +37,11 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <status.h>
 #include <vector.h>
 #include <lang.h>
 #include <vm.h>
 
-static void bc_vec_grow(BcVec *restrict v, size_t n) {
+void bc_vec_grow(BcVec *restrict v, size_t n) {
 
 	size_t len, cap = v->cap;
 	sig_atomic_t lock;
